@@ -6,12 +6,12 @@ class IncludeEmpty(MetaDataObject):
         super(IncludeEmpty, self).__init__()
 
     @classmethod
-    def decode(cls, src_dir, file_name, dest_dir, dest_path, version):
-        raise Exception('Так быть не должно, это класс обслуживает вложенные объекты')
+    def decode(cls, src_dir, file_name, dest_dir, dest_path, version, parent_type=None):
+        raise Exception('Так быть не должно, этот класс обслуживает вложенные объекты')
 
     @classmethod
     def decode_local_include(cls, parent, header_data, src_dir, dest_dir, dest_path, version):
         return
 
     def encode_object(self, src_dir, file_name, dest_dir, version):
-        raise Exception('Так быть не должно, это класс обслуживает вложенные объекты')
+        raise Exception('Так быть не должно, этот класс обслуживает вложенные объекты')
